#include "main.h"
#include "NT3915.h"

const unsigned char  Font8x16[96][16];
#define EM 0x1030
#define DOCR 0x0213
int colors[]=
{
  0xf800,  // Rot
  0x07e0,  // Gruen
  0x001f,  // Blau
  0xffe0,  // Gelb
  0x0000,  // Schwarz
  0x07ff,  // Hellblau
  0xf81f,  // Lila
  0xffff  // Weiss
};

#define SHIFTLCD(DATA) ((DATA & 0x3FFF) + ((DATA & 0xC000)<<1));
/**********************************************************
 Draw a box
**********************************************************/
void DrawFill(BYTE x,BYTE y,BYTE w,BYTE h,UINT pixel)
{
    UINT loop,loop2 = 0;
    UINT PixelCount = (w*h)+100;
    UINT x2 = x + w;
    UINT y2 = y + h;

    LCD_SetRamAddr(x,x2,y,y2);
    IO0CLR = CS;
    IO0SET = RS;
    for(loop=0;loop<PixelCount;loop++)
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(pixel);
        IO0CLR = WR;
    }
    //IO0SET = WR;
    IO0SET = CS;
}
/**********************************************************
 Draw a box
**********************************************************/
void DrawBox(BYTE x,BYTE y,BYTE w,BYTE h,UINT pixel)
{
    BYTE loop = 0;
    UINT PixelCount=0;
    BYTE x2 = x + w;
    BYTE y2 = y + h;
    PixelCount = w+h;

    LCD_SetRamAddr(x,x2,y,y);
    IO0CLR = CS;
    IO0SET = RS;
    for(loop=0;loop<PixelCount;loop++)
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(pixel);
        IO0CLR = WR;
    }
    LCD_SetRamAddr(x,x2, y2,y2);
    IO0CLR = CS;
    IO0SET = RS;
    for(loop=0;loop<PixelCount;loop++)
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(pixel);
        IO0CLR = WR;
    }
    LCD_SetRamAddr(x,x, y,y2);
    IO0CLR = CS;
    IO0SET = RS;
    for(loop=0;loop<PixelCount;loop++)
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(pixel);
        IO0CLR = WR;
    }
    LCD_SetRamAddr(x2,x2, y,y2);
    IO0CLR = CS;
    IO0SET = RS;
    for(loop=0;loop<PixelCount;loop++)
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(pixel);
        IO0CLR = WR;
    }
    //IO0SET = WR;
    IO0SET = CS;
}
/**********************************************************
 Load a byte to port
**********************************************************/
void LoadByte(int byte, int start)
{
    IO0CLR = SHIFTLCD(0xFFFF);
    IO0PIN  |= SHIFTLCD(byte);
}
/**********************************************************
 Write String of Characters to LCD
**********************************************************/
void LCD_ShowString(unsigned char x,unsigned char y,unsigned int fcolor,unsigned int bcolor,unsigned char *p)
{ 
    int oldx = x;
    int oldy = y;
   while(*p!='\0')
   {       
     LCD_ShowChar(x,y,fcolor,bcolor,*p);
    if((x+8)<LCD_SIZE_X)
    {
        x+=8;
    }
    else
    {
        x=oldx;
        if((y+16)<LCD_SIZE_Y)
            y+=16;
        else
            y = oldy;
    }
     p++;
   }
}
/**********************************************************
 Write Character to LCD
**********************************************************/
void LCD_ShowChar(unsigned char x,unsigned char y,unsigned int fcolor,unsigned int bcolor,unsigned char ch)
{       
   unsigned char temp;
   unsigned char pos,t;
   unsigned char  CHAR_W,CHAR_H;
   
   CHAR_W = 8;         //8*16
   CHAR_H = 16;

   if(x>(LCD_SIZE_X-CHAR_W)||y>(LCD_SIZE_Y-CHAR_H))
   return;
   
   LCD_SetRamAddr(x, x+CHAR_W-1, y,y+CHAR_H-1);
   ch = ch-32;                       

   for(pos=0;pos<CHAR_H;pos++)  
   {
      temp= Font8x16[ch][pos];
      
      for(t=0;t<CHAR_W;t++)
      { 
        if(temp&0x80)
        LCD_Wirte_Data16(fcolor);  //textcolor
        else 
        LCD_Wirte_Data16(bcolor);  //backcolor
        temp<<=1; 
      }
   }
}
/**********************************************************
 Write Command/Data to LCD
 TYPE = 0: command    1: data
**********************************************************/
void LCD_Write(int  type, int value)  
{
    if(type == 0){
        IO0CLR = RS;
    } else {
        IO0SET = RS;
    }
    Delay_US(1);
    IO0CLR = WR;
    LoadByte((value&0xffff),LCD_DATA);
    IO0SET = WR;
}
/**********************************************************
 Write to Register
**********************************************************/
void Reg_Write(int reg,int value) 
{
   LCD_Write(TYPE_LCD_COMMAND,reg);
   LCD_Write(TYPE_LCD_DATA,value);
}

/**********************************************************
Setting the frame on the display
**********************************************************/
void LCD_SetRamAddr(int xStart, int xEnd, int yStart, int yEnd) 
{
   int VerPos,HorPos,StartAddr;
   
   IO0CLR = CS;
   HorPos    = (int)((xEnd<<8)|xStart);
   VerPos    = (int)((yEnd<<8)|yStart );
   StartAddr = (int)((yStart<<8)|xStart);

   Reg_Write(0x16, HorPos);
   Reg_Write(0x17, VerPos);

   Reg_Write(0x21, StartAddr);             // 0x21
   LCD_Write(TYPE_LCD_COMMAND,0x22);     // 0x22
   IO0SET = CS;
}
/**********************************************************
 Initialize LCD
**********************************************************/
void  LCD_init(void)
{
    IO0CLR = RES;
    Delay_MS(20);
    IO0SET = RES;
    Delay_MS(20);

    IO0SET = CS;
    IO0CLR = RS;
    IO0SET = RD;
    IO0SET = WR;
    IO0CLR = CS;
    Delay_MS(10);
    
   Reg_Write(0x0007,0x0100); // Display control GON=0,DTE=0,D1=0,D0=0,
   Reg_Write(0x000d,0x0000); // Power control 4  PON=0
   Reg_Write(0x0000,0x0001); // OSC Start
   Delay_MS(20);
   Reg_Write(0x000e,0x2000);     // Power control 5 VCOMG=1
   Reg_Write(0x000c,0x0001); // Power contorl 3 VCI=VDD , VCI1=VCI*1
   Reg_Write(0x000d,0x0003); // Power control 4 VLCD
   Reg_Write(0x0004,0x0000); // Power control 2 CAD=0
   Reg_Write(0x000d,0x0903); // Power control 4 VREG2OUT=-5.5*VCI
   Reg_Write(0x0003,0x0414); // Power Control 1
   Reg_Write(0x000e,0x1212);         // Power control 5  Vcom
   Delay_MS(50);                 // VCOMH(3V~VREG1OUT) , VCOML(0.5~1V)

   Reg_Write(0x000d,0x031d); // 0x318 // Power control 4  PON=1  VRL3~VRL0=1001 -->VREG2OUT=-5.5*VCI
                                // VRH3~VRH0=0011 -->VREG1OUT=1.65*REGP=4.62V , REGP=VCI1

   Reg_Write(0x0001,DOCR); //0x0113 Driver output contorl SM,GS,SS NL4~NL0=10011(1/176Duty)
   Reg_Write(0x0002,0x0700); // LCD-Driving-waveform control  FLD1 FLD0 B/C EOR NW5~NW0=001101
   Reg_Write(0x0005,EM); // Entry Mode RGB MODE , I/D1 I/D0=11---  0x1030
   Reg_Write(0x0006,0x0000);
   Reg_Write(0x000b,0x4001);
   Reg_Write(0x000f,0x0000); // GATE SCAN POSITION  G17 Start scanf G17->G176

   Reg_Write(0x0011,0x0000);
   Reg_Write(0x0014,0x9F00);
   Reg_Write(0x0015,0x0000);
   Reg_Write(0x0016,0x7F00); // Horizontal window address 128
   Reg_Write(0x0017,0x9F00); // Vertical window Address 160
   Reg_Write(0x0021,0x0000);

   Reg_Write(0x0030,0x0000);
   Reg_Write(0x0031,0x0204);
   Reg_Write(0x0032,0x0302);
   Reg_Write(0x0033,0x0000);
   Reg_Write(0x0034,0x0504);
   Reg_Write(0x0035,0x0405);
   Reg_Write(0x0036,0x0707);
   Reg_Write(0x0037,0x0100);
   Reg_Write(0x003a,0x1506);
   Reg_Write(0x003b,0x000f);

   Reg_Write(0x0007,0x0005);
   Reg_Write(0x0007,0x0025);
   Reg_Write(0x0007,0x0027);
   Reg_Write(0x0007,0x0137);
   LCD_Write(TYPE_LCD_COMMAND,0x22);     // 0x22
   Delay_MS(10);
   //IO0SET = CS;
}
/**********************************************************
 Draw on Screen
**********************************************************/
void  LCD_Draw16(unsigned char x,unsigned char y,unsigned char width,unsigned char height,const unsigned int *dat)
{
    int num;
    int len = width * height;
    int x2 = (width+x)-1;
    int y2 = (height+y)-1;

    LCD_SetRamAddr(x,x2, y,y2);
    IO0CLR = CS;
    IO0SET = RS;
    for(num=len;num>0;num--)          //160*128=20480
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(*dat++);
        IO0CLR = WR;
    }
    //IO0SET = WR;
    IO0SET = CS;
}
/**********************************************************
 Clear Screen
**********************************************************/
void  LCD_clear(int n)
{
    int num;
    
    
    LCD_SetRamAddr(0,127, 0,159);
    IO0CLR = CS;
    IO0SET = RS;
    for(num=20480;num>0;num--)          //160*128=20480
    {
        IO0SET = WR;
        IO0CLR = SHIFTLCD(0xFFFF);
        IO0PIN  |= SHIFTLCD(n);
        IO0CLR = WR;
    }
    IO0SET = WR;
    IO0SET = CS;
}
/**********************************************************
  Horizontales Anzeigen eines Musters in Farbe
**********************************************************/
void LCD_color_H(void)
{
    int num;
    int n;
    int color;

    IO0CLR = CS;
    IO0SET = RS;
    for(n=0;n<8;n++)
    {
        color =  (colors[n]<<2);
        for(num=2560;num>0;num--)          //160*128=20480
        {
            IO0SET = WR;
            IO0CLR = SHIFTLCD(0xFFFF);
            IO0PIN  |= SHIFTLCD(color);
            IO0CLR = WR;
        }
    }
    IO0SET = WR;
    IO0SET = CS;
}

/**********************************************************
  Horizontales Anzeigen eines Musters in Farbe
**********************************************************/
void LCD_color_V(void)
{
   int num;
   int n,x1,x2;
   x1 = 0;
   x2 = 16;
   
   for(n=0;n<8;n++)
   {
     LCD_SetRamAddr(x1, x2-1, 0,159);
     x1 = x2;
     x2 = x2+16; 

     for(num=16*160;num>0;num--)
     {
       LCD_Wirte_Data16(colors[n]);
     }
   }
}
/**********************************************************
 Schreiben 8-bit Daten auf das Display
**********************************************************/
void  LCD_Write_Data8(int value)
{
    IO0CLR = CS;
    IO0SET = RS;
   LoadByte(value,LCD_DATA);
    IO0CLR = WR;
    //Delay_US(1);
    IO0SET = WR;
    IO0SET = CS;
}

/**********************************************************
 Schreiben 8-bit Daten auf das Display
**********************************************************/
void LCD_Wirte_Data16(int value)   
{
    IO0CLR = CS;
    IO0SET = RS;
   LoadByte(value,LCD_DATA);
    IO0CLR = WR;
    //Delay_US(1);
    IO0SET = WR;
    //IO0SET = CS;
}
void LCD_Wirte_DataF(int value)   
{
   LoadByte(value,LCD_DATA);
    IO0CLR = WR;
    IO0SET = WR;
}
/**********************************************************
 Anzeige in Farbe
**********************************************************/
void LCD_color(void)
{
   int num;
   int n;

   for(n=0;n<8;n++)
   {
     LCD_SetRamAddr(0,127, 0,159);
     
     for(num=20480;num>0;num--)            //160*128=20480
     {
       LCD_Wirte_Data16(colors[n]);
     }
     Delay_MS(500);
   }
}

const unsigned char  Font8x16[96][16] = //Font8x16
{
//0x08,0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00, // columns, rows, num_bytes_per_char
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // space 0x20
{0x00,0x00,0x18,0x3C,0x3C,0x3C,0x18,0x18,0x18,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, // !
{0x00,0x63,0x63,0x63,0x22,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // "
{0x00,0x00,0x00,0x36,0x36,0x7F,0x36,0x36,0x36,0x7F,0x36,0x36,0x00,0x00,0x00,0x00}, // #
{0x0C,0x0C,0x3E,0x63,0x61,0x60,0x3E,0x03,0x03,0x43,0x63,0x3E,0x0C,0x0C,0x00,0x00}, // $
{0x00,0x00,0x00,0x00,0x00,0x61,0x63,0x06,0x0C,0x18,0x33,0x63,0x00,0x00,0x00,0x00}, // %
{0x00,0x00,0x00,0x1C,0x36,0x36,0x1C,0x3B,0x6E,0x66,0x66,0x3B,0x00,0x00,0x00,0x00}, // &
{0x00,0x30,0x30,0x30,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // '
{0x00,0x00,0x0C,0x18,0x18,0x30,0x30,0x30,0x30,0x18,0x18,0x0C,0x00,0x00,0x00,0x00}, // (
{0x00,0x00,0x18,0x0C,0x0C,0x06,0x06,0x06,0x06,0x0C,0x0C,0x18,0x00,0x00,0x00,0x00}, // )
{0x00,0x00,0x00,0x00,0x42,0x66,0x3C,0xFF,0x3C,0x66,0x42,0x00,0x00,0x00,0x00,0x00}, // *
{0x00,0x00,0x00,0x00,0x18,0x18,0x18,0xFF,0x18,0x18,0x18,0x00,0x00,0x00,0x00,0x00}, // +
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x18,0x30,0x00,0x00}, // ,
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // -
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, // .
{0x00,0x00,0x01,0x03,0x07,0x0E,0x1C,0x38,0x70,0xE0,0xC0,0x80,0x00,0x00,0x00,0x00}, // / (forward slash)
{0x00,0x00,0x3E,0x63,0x63,0x63,0x6B,0x6B,0x63,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // 0 0x30
{0x00,0x00,0x0C,0x1C,0x3C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x3F,0x00,0x00,0x00,0x00}, // 1
{0x00,0x00,0x3E,0x63,0x03,0x06,0x0C,0x18,0x30,0x61,0x63,0x7F,0x00,0x00,0x00,0x00}, // 2
{0x00,0x00,0x3E,0x63,0x03,0x03,0x1E,0x03,0x03,0x03,0x63,0x3E,0x00,0x00,0x00,0x00}, // 3

{0x00,0x00,0x06,0x0E,0x1E,0x36,0x66,0x66,0x7F,0x06,0x06,0x0F,0x00,0x00,0x00,0x00}, // 4
{0x00,0x00,0x7F,0x60,0x60,0x60,0x7E,0x03,0x03,0x63,0x73,0x3E,0x00,0x00,0x00,0x00}, // 5
{0x00,0x00,0x1C,0x30,0x60,0x60,0x7E,0x63,0x63,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // 6
{0x00,0x00,0x7F,0x63,0x03,0x06,0x06,0x0C,0x0C,0x18,0x18,0x18,0x00,0x00,0x00,0x00}, // 7
{0x00,0x00,0x3E,0x63,0x63,0x63,0x3E,0x63,0x63,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // 8
{0x00,0x00,0x3E,0x63,0x63,0x63,0x63,0x3F,0x03,0x03,0x06,0x3C,0x00,0x00,0x00,0x00}, // 9
{0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x00}, // :
{0x00,0x00,0x00,0x00,0x00,0x18,0x18,0x00,0x00,0x00,0x18,0x18,0x18,0x30,0x00,0x00}, // ;
{0x00,0x00,0x00,0x06,0x0C,0x18,0x30,0x60,0x30,0x18,0x0C,0x06,0x00,0x00,0x00,0x00}, // <
{0x00,0x00,0x00,0x00,0x00,0x00,0x7E,0x00,0x00,0x7E,0x00,0x00,0x00,0x00,0x00,0x00}, // =
{0x00,0x00,0x00,0x60,0x30,0x18,0x0C,0x06,0x0C,0x18,0x30,0x60,0x00,0x00,0x00,0x00}, // >
{0x00,0x00,0x3E,0x63,0x63,0x06,0x0C,0x0C,0x0C,0x00,0x0C,0x0C,0x00,0x00,0x00,0x00}, // ?
{0x00,0x00,0x3E,0x63,0x63,0x6F,0x6B,0x6B,0x6E,0x60,0x60,0x3E,0x00,0x00,0x00,0x00}, // @ 0x40
{0x00,0x00,0x08,0x1C,0x36,0x63,0x63,0x63,0x7F,0x63,0x63,0x63,0x00,0x00,0x00,0x00}, // A
{0x00,0x00,0x7E,0x33,0x33,0x33,0x3E,0x33,0x33,0x33,0x33,0x7E,0x00,0x00,0x00,0x00}, // B
{0x00,0x00,0x1E,0x33,0x61,0x60,0x60,0x60,0x60,0x61,0x33,0x1E,0x00,0x00,0x00,0x00}, // C
{0x00,0x00,0x7C,0x36,0x33,0x33,0x33,0x33,0x33,0x33,0x36,0x7C,0x00,0x00,0x00,0x00}, // D
{0x00,0x00,0x7F,0x33,0x31,0x34,0x3C,0x34,0x30,0x31,0x33,0x7F,0x00,0x00,0x00,0x00}, // E
{0x00,0x00,0x7F,0x33,0x31,0x34,0x3C,0x34,0x30,0x30,0x30,0x78,0x00,0x00,0x00,0x00}, // F
{0x00,0x00,0x1E,0x33,0x61,0x60,0x60,0x6F,0x63,0x63,0x37,0x1D,0x00,0x00,0x00,0x00}, // G

{0x00,0x00,0x63,0x63,0x63,0x63,0x7F,0x63,0x63,0x63,0x63,0x63,0x00,0x00,0x00,0x00}, // H
{0x00,0x00,0x3C,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, // I
{0x00,0x00,0x0F,0x06,0x06,0x06,0x06,0x06,0x06,0x66,0x66,0x3C,0x00,0x00,0x00,0x00}, // J
{0x00,0x00,0x73,0x33,0x36,0x36,0x3C,0x36,0x36,0x33,0x33,0x73,0x00,0x00,0x00,0x00}, // K
{0x00,0x00,0x78,0x30,0x30,0x30,0x30,0x30,0x30,0x31,0x33,0x7F,0x00,0x00,0x00,0x00}, // L
{0x00,0x00,0x63,0x77,0x7F,0x6B,0x63,0x63,0x63,0x63,0x63,0x63,0x00,0x00,0x00,0x00}, // M
{0x00,0x00,0x63,0x63,0x73,0x7B,0x7F,0x6F,0x67,0x63,0x63,0x63,0x00,0x00,0x00,0x00}, // N
{0x00,0x00,0x1C,0x36,0x63,0x63,0x63,0x63,0x63,0x63,0x36,0x1C,0x00,0x00,0x00,0x00}, // O
{0x00,0x00,0x7E,0x33,0x33,0x33,0x3E,0x30,0x30,0x30,0x30,0x78,0x00,0x00,0x00,0x00}, // P   0x50
{0x00,0x00,0x3E,0x63,0x63,0x63,0x63,0x63,0x63,0x6B,0x6F,0x3E,0x06,0x07,0x00,0x00}, // Q
{0x00,0x00,0x7E,0x33,0x33,0x33,0x3E,0x36,0x36,0x33,0x33,0x73,0x00,0x00,0x00,0x00}, // R
{0x00,0x00,0x3E,0x63,0x63,0x30,0x1C,0x06,0x03,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // S
{0x00,0x00,0xFF,0xDB,0x99,0x18,0x18,0x18,0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, // T
{0x00,0x00,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // U
{0x00,0x00,0x63,0x63,0x63,0x63,0x63,0x63,0x63,0x36,0x1C,0x08,0x00,0x00,0x00,0x00}, // V
{0x00,0x00,0x63,0x63,0x63,0x63,0x63,0x6B,0x6B,0x7F,0x36,0x36,0x00,0x00,0x00,0x00}, // W
{0x00,0x00,0xC3,0xC3,0x66,0x3C,0x18,0x18,0x3C,0x66,0xC3,0xC3,0x00,0x00,0x00,0x00}, // X
{0x00,0x00,0xC3,0xC3,0xC3,0x66,0x3C,0x18,0x18,0x18,0x18,0x3C,0x00,0x00,0x00,0x00}, // Y
{0x00,0x00,0x7F,0x63,0x43,0x06,0x0C,0x18,0x30,0x61,0x63,0x7F,0x00,0x00,0x00,0x00}, // Z
{0x00,0x00,0x3C,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x30,0x3C,0x00,0x00,0x00,0x00}, // [

{0x00,0x00,0x80,0xC0,0xE0,0x70,0x38,0x1C,0x0E,0x07,0x03,0x01,0x00,0x00,0x00,0x00}, // \ (back slash)
{0x00,0x00,0x3C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x3C,0x00,0x00,0x00,0x00}, // ]
{0x08,0x1C,0x36,0x63,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // ^
{0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00}, // _
{0x18,0x18,0x0C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // `    0x60
{0x00,0x00,0x00,0x00,0x00,0x3C,0x46,0x06,0x3E,0x66,0x66,0x3B,0x00,0x00,0x00,0x00}, // a
{0x00,0x00,0x70,0x30,0x30,0x3C,0x36,0x33,0x33,0x33,0x33,0x6E,0x00,0x00,0x00,0x00}, // b
{0x00,0x00,0x00,0x00,0x00,0x3E,0x63,0x60,0x60,0x60,0x63,0x3E,0x00,0x00,0x00,0x00}, // c
{0x00,0x00,0x0E,0x06,0x06,0x1E,0x36,0x66,0x66,0x66,0x66,0x3B,0x00,0x00,0x00,0x00}, // d
{0x00,0x00,0x00,0x00,0x00,0x3E,0x63,0x63,0x7E,0x60,0x63,0x3E,0x00,0x00,0x00,0x00}, // e
{0x00,0x00,0x1C,0x36,0x32,0x30,0x7C,0x30,0x30,0x30,0x30,0x78,0x00,0x00,0x00,0x00}, // f
{0x00,0x00,0x00,0x00,0x00,0x3B,0x66,0x66,0x66,0x66,0x3E,0x06,0x66,0x3C,0x00,0x00}, // g
{0x00,0x00,0x70,0x30,0x30,0x36,0x3B,0x33,0x33,0x33,0x33,0x73,0x00,0x00,0x00,0x00}, // h
{0x00,0x00,0x0C,0x0C,0x00,0x1C,0x0C,0x0C,0x0C,0x0C,0x0C,0x1E,0x00,0x00,0x00,0x00}, // i
{0x00,0x00,0x06,0x06,0x00,0x0E,0x06,0x06,0x06,0x06,0x06,0x66,0x66,0x3C,0x00,0x00}, // j
{0x00,0x00,0x70,0x30,0x30,0x33,0x33,0x36,0x3C,0x36,0x33,0x73,0x00,0x00,0x00,0x00}, // k
{0x00,0x00,0x1C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x0C,0x1E,0x00,0x00,0x00,0x00}, // l
{0x00,0x00,0x00,0x00,0x00,0x6E,0x7F,0x6B,0x6B,0x6B,0x6B,0x6B,0x00,0x00,0x00,0x00}, // m
{0x00,0x00,0x00,0x00,0x00,0x6E,0x33,0x33,0x33,0x33,0x33,0x33,0x00,0x00,0x00,0x00}, // n
{0x00,0x00,0x00,0x00,0x00,0x3E,0x63,0x63,0x63,0x63,0x63,0x3E,0x00,0x00,0x00,0x00}, // o

{0x00,0x00,0x00,0x00,0x00,0x6E,0x33,0x33,0x33,0x33,0x3E,0x30,0x30,0x78,0x00,0x00}, // p    0x70
{0x00,0x00,0x00,0x00,0x00,0x3B,0x66,0x66,0x66,0x66,0x3E,0x06,0x06,0x0F,0x00,0x00}, // q
{0x00,0x00,0x00,0x00,0x00,0x6E,0x3B,0x33,0x30,0x30,0x30,0x78,0x00,0x00,0x00,0x00}, // r
{0x00,0x00,0x00,0x00,0x00,0x3E,0x63,0x38,0x0E,0x03,0x63,0x3E,0x00,0x00,0x00,0x00}, // s
{0x00,0x00,0x08,0x18,0x18,0x7E,0x18,0x18,0x18,0x18,0x1B,0x0E,0x00,0x00,0x00,0x00}, // t
{0x00,0x00,0x00,0x00,0x00,0x66,0x66,0x66,0x66,0x66,0x66,0x3B,0x00,0x00,0x00,0x00}, // u
{0x00,0x00,0x00,0x00,0x00,0x63,0x63,0x36,0x36,0x1C,0x1C,0x08,0x00,0x00,0x00,0x00}, // v
{0x00,0x00,0x00,0x00,0x00,0x63,0x63,0x63,0x6B,0x6B,0x7F,0x36,0x00,0x00,0x00,0x00}, // w
{0x00,0x00,0x00,0x00,0x00,0x63,0x36,0x1C,0x1C,0x1C,0x36,0x63,0x00,0x00,0x00,0x00}, // x
{0x00,0x00,0x00,0x00,0x00,0x63,0x63,0x63,0x63,0x63,0x3F,0x03,0x06,0x3C,0x00,0x00}, // y
{0x00,0x00,0x00,0x00,0x00,0x7F,0x66,0x0C,0x18,0x30,0x63,0x7F,0x00,0x00,0x00,0x00}, // z
{0x00,0x00,0x0E,0x18,0x18,0x18,0x70,0x18,0x18,0x18,0x18,0x0E,0x00,0x00,0x00,0x00}, // {
{0x00,0x00,0x18,0x18,0x18,0x18,0x18,0x00,0x18,0x18,0x18,0x18,0x18,0x00,0x00,0x00}, // |
{0x00,0x00,0x70,0x18,0x18,0x18,0x0E,0x18,0x18,0x18,0x18,0x70,0x00,0x00,0x00,0x00}, // }
{0x00,0x00,0x3B,0x6E,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // ~
{0x00,0x70,0xD8,0xD8,0x70,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00}, // DEL

};