/***************************************************

Bitmap file format to N6610 LCD format
yus    - http://projectproto.blogspot.com/
May 2010

*****************************************************/
#include "main.h"
#include "lcd_bmp.h"
/***** private variables *****/
BYTE RGB_buff1[4608] = {0};            // for pf_read of bitmap data        

DWORD bitmap_width, bitmap_height;
UINT pixel, row, column, line;
DWORD data_start, count;
WORD rb;

/***** private functions *****/
void draw_from_24bpp(void);

// 24-bit Color to 16-bit Color RRRRRGGGGGGBBBBB format
#define RGB16(R,G,B)  ((B >> 3) + ((G >> 2)<<5) + ((R >> 3)<<11));

/***** exported function *****/
void draw_bitmap(char *filename)
{
    BYTE DW_buff[4] = {0};
    BYTE W_buff[2] = {0};     
    DWORD compression_method;
    WORD bits_per_pixel;    
    
    //pf_lseek(0x00);
    pf_read(W_buff, 2, &rb);            // 0x00
    if( (W_buff[0]=='B') && (W_buff[1]=='M') ){
        pf_lseek(0x0A);                    // 0x0A    - offset where the bitmap data (pixels) can be found.
        pf_read(DW_buff, 4, &rb);
        data_start = LD_DWORD(DW_buff);

        pf_read(DW_buff, 4, &rb);        // 0x0E (dummy read)

        pf_read(DW_buff, 4, &rb);        // 0x12
        bitmap_width = LD_DWORD(DW_buff);            
        pf_read(DW_buff, 4, &rb);        // 0x16
        bitmap_height = LD_DWORD(DW_buff);
        if( (bitmap_width>128) || (bitmap_height>160) ){
            LCD_ShowString(2,10,BLACK,WHITE,"Too Large!");
            return;
        }
        
        pf_read(W_buff, 2, &rb);        // 0x1A

        pf_read(W_buff, 2, &rb);        // 0x1C    (bits/pixel)
        bits_per_pixel = LD_WORD(W_buff);
        if( (bits_per_pixel!=24) ){
            LCD_ShowString(2,10,BLACK,WHITE,"Not Supported!");
            return;
        }

        pf_read(DW_buff, 4, &rb);        // 0x1E
        compression_method = LD_DWORD(DW_buff);
        if( compression_method != 0 ){
            LCD_ShowString(2,10,BLACK,WHITE,"Not Supported!");
            return;
        }

        if(bits_per_pixel == 24)
            memset(RGB_buff1,0,1152);
            draw_from_24bpp();


    }
    else{
       LCD_ShowString(2,10,BLACK,WHITE,"Invalid File!");
    }
}

/*** 24 bits per pixel format ***/
void draw_from_24bpp(void)
{
    DWORD x, y, total;
    UINT BuffC = 4608;

    UINT num;
    UINT len = (bitmap_width * bitmap_height)*3;
    UINT loopC = len / BuffC;
    UINT x2 = bitmap_width-1;
    UINT y2 = bitmap_height-1;
    UINT loopP = 1;
    UINT w;
    UINT q = BuffC-384;
    UINT z = 0;

    if(len % BuffC) 
        loopC += 1;
    LCD_clear(BLACK);

    pf_lseek((data_start+len)-BuffC);        // go to the start of bitmap data

     LCD_SetRamAddr(0,x2, 0,y2);
    IO0CLR = CS;
    IO0SET = RS;

    while(loopC-1)
    {
        pf_read(RGB_buff1, BuffC, &rb);
        loopP++;
        for(num=0;num<BuffC;num+=3)          //160*128=20480
        {
            pixel = RGB16(RGB_buff1[(q+z+2)], RGB_buff1[(q+z+1)], RGB_buff1[(q+z)]); 
            IO0SET = WR;
            IO0CLR =  (0xFFFF<<LCD_DATA);
            IO0PIN  |= (pixel<<LCD_DATA);
            IO0CLR = WR;
            z=z+3;
            if(z == 384)
            {
                z= 0;
                q=q-384;
            }
        }
        q = BuffC - 384;

        w = ((data_start+len)-(BuffC*loopP));
        if(w < data_start) w = data_start;
        pf_lseek(w);        // go to the start of bitmap data
        loopC--;
    }
    IO0SET = WR;
    IO0SET = CS;
}



