#include "spi.h"

/********************
    Init SPI 0
********************/
void INIT_SPI(BYTE speed)
{
    char dummy;     //Temp Dummy Variable
    PINSEL0 |= 0x20000000;  // All SPI1 pins are set for SPI Mode and Not GPIO
    PINSEL1 |= 0x140;             // All SPI1 pins are set for SPI Mode and Not GPIO

    DESELECT();             // Deselect the SD Card
    SSPCR0 = 0x7;       // Check the SCR BITS HERE******
    SSPCR1 = 0x2;


    // Set speed to : (CCLK /APB)/S0SPCCR = ( (CCLK(50Mhz) / APB(1)))
    if(speed==0)
    {
        SSPCPSR = 126;   // (50Mhz / 0+1) / 126 = 396,825hz or close to 400khz
    }
    else
    {
         SSPCPSR = 2;       // (50Mhz / 0+1) / 2 = 25Mhz 
    }
    dummy = SSPDR;     //Dummy Read
}
/********************
    Send Byte VIA SPI0
********************/
BYTE xmit_spi(BYTE data)
{
    unsigned char temp;
    while(!(SSPSR & 0x02))     // Wait for SPI0 transfer complete flag
    SSPDR = data;                   // Load Data to SPI0 Register and Send
    while (!(SSPSR & 0x04));
    temp = SSPDR;                // Receive any data
    return temp;                   // Return Data
}
/********************
    Get Byte VIA SPI0
********************/
BYTE rcv_spi (void)
 {
    unsigned char temp;
    while(!(SSPSR & 0x02))     // Wait for SPI0 transfer complete flag
    SSPDR = 0xFF;                   // Load Data to SPI0 Register and Send
    while (!(SSPSR & 0x04));
    temp = SSPDR;                // Receive any data
    return temp;                   // Return Data
}
/********************
    SSEL0 = Selected (LOW)
********************/
void SELECT(void)
{
    IO0CLR = SD_CS;      // Set SSEL aka CD line low
    rcv_spi();                  // Send out pulses to clear the port
}
/********************
    SSEL0 = Deselected (High)
********************/
void DESELECT(void)
{
    IO0SET = SD_CS;      // Set SSEL aka CD line High 
}
/********************
    Deselect the card and release SPI bus          
********************/
void release_spi (void)
{
    DESELECT();         //Deselect 
    rcv_spi();               // Send out pulses to clear the port
}